@@ -132,15 +132,15 @@ def expand_labels(label_image, distance=1):
     labels_out[dilate_mask] = nearest_labels
     return labels_out
 
-def SimplePrediction(x, UnetModel, StarModel, n_tiles = (2,2), UseProbability = True, min_size = 20):
+def SimplePrediction(x, UnetModel, StarModel, n_tiles = (2,2), UseProbability = True, min_size = 20, axis = 'ZYX'):
     
                
     
              
                                            
-                      Mask = UNETPrediction3D(x, UnetModel, min_size, n_tiles, 'YX')
+                      Mask = UNETPrediction3D(x, UnetModel, n_tiles, axis)
                       
-                      SmartSeeds, _, StarImage = STARPrediction3D(x, StarModel, min_size, n_tiles, MaskImage = Mask, smartcorrection = None, UseProbability = UseProbability)
+                      SmartSeeds, _, StarImage = STARPrediction3D(x, StarModel, n_tiles, MaskImage = Mask, smartcorrection = None, UseProbability = UseProbability)
                       
                       SmartSeeds = SmartSeeds.astype('uint16') 
                      
@@ -510,13 +510,14 @@ n_tiles = (1,2,2), doMask = True, smartcorrection = None, threshold = 20, projec
     
     SizedMask[:, :Mask.shape[1], :Mask.shape[2]] = Mask
     
-
+    
     SmartSeeds, _, StarImage = STARPrediction3D(gaussian_filter(image,filtersize), StarModel,  n_tiles, MaskImage = Mask, UseProbability = UseProbability, smartcorrection = smartcorrection)
     #Upsample images back to original size
     for i in range(0, Mask.shape[0]):
         SmartSeeds[i,:] = remove_small_objects(SmartSeeds[i,:].astype('uint16'), min_size = min_size)
         
-    SmartSeeds = RemoveLabels(SmartSeeds)       
+    SmartSeeds = RemoveLabels(SmartSeeds) 
+    SmartSeeds = fill_label_holes(SmartSeeds.astype('uint16'))
     SizedSmartSeeds[:, :SmartSeeds.shape[1], :SmartSeeds.shape[2]] = SmartSeeds
             
     imwrite((StarDistResults + Name+ '.tif' ) , StarImage.astype('uint16'))
@@ -704,13 +705,18 @@ def STARPrediction3D(image, model, n_tiles, MaskImage = None, smartcorrection =
 
 
     StarImage = MidImage[:image.shape[0],:shape[0],:shape[1]]
-    SmallDistance = MaxProjectDist(SmallDistance, axis=-1)
+    if UseProbability == False:
+        
+        SmallDistance = MaxProjectDist(SmallDistance, axis=-1)
+        Distance = np.zeros([SmallDistance.shape[0] * grid[0], SmallDistance.shape[1] * grid[1], SmallDistance.shape[2] * grid[2] ])
+    
     Probability = np.zeros([SmallProbability.shape[0] * grid[0],SmallProbability.shape[1] * grid[1], SmallProbability.shape[2] * grid[2] ])
-    Distance = np.zeros([SmallDistance.shape[0] * grid[0], SmallDistance.shape[1] * grid[1], SmallDistance.shape[2] * grid[2] ])
+    
     #We only allow for the grid parameter to be 1 along the Z axis
     for i in range(0, SmallProbability.shape[0]):
         Probability[i,:] = cv2.resize(SmallProbability[i,:], dsize=(SmallProbability.shape[2] * grid[2] , SmallProbability.shape[1] * grid[1] ))
-        Distance[i,:] = cv2.resize(SmallDistance[i,:], dsize=(SmallDistance.shape[2] * grid[2] , SmallDistance.shape[1] * grid[1] ))
+        if UseProbability == False:
+            Distance[i,:] = cv2.resize(SmallDistance[i,:], dsize=(SmallDistance.shape[2] * grid[2] , SmallDistance.shape[1] * grid[1] ))
     
     if UseProbability:
         
